@@ -888,6 +888,15 @@ InstanceTypeType = Literal[
     "c6gn.large",
     "c6gn.medium",
     "c6gn.xlarge",
+    "c6i.12xlarge",
+    "c6i.16xlarge",
+    "c6i.24xlarge",
+    "c6i.2xlarge",
+    "c6i.32xlarge",
+    "c6i.4xlarge",
+    "c6i.8xlarge",
+    "c6i.large",
+    "c6i.xlarge",
     "cc1.4xlarge",
     "cc2.8xlarge",
     "cg1.4xlarge",
@@ -928,6 +937,14 @@ InstanceTypeType = Literal[
     "g4dn.8xlarge",
     "g4dn.metal",
     "g4dn.xlarge",
+    "g5.12xlarge",
+    "g5.16xlarge",
+    "g5.24xlarge",
+    "g5.2xlarge",
+    "g5.48xlarge",
+    "g5.4xlarge",
+    "g5.8xlarge",
+    "g5.xlarge",
     "h1.16xlarge",
     "h1.2xlarge",
     "h1.4xlarge",
@@ -1729,6 +1746,7 @@ ServiceName = Literal[
     "mgh",
     "mgn",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -1762,6 +1780,7 @@ ServiceName = Literal[
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
